import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: settingsWindow
    tools: settingsTools
    orientationLock: PageOrientation.LockPortrait

    function create_listview_fav_teams(list){
        var i = 0
        fav_team_listmodel.clear()
        for (i = 0; i<list.length; i++){
            fav_team_listmodel.append({"name": list[i]})
        }
    }

    function create_listview_fav_leagues(list){
        var i = 0
        fav_league_listmodel.clear()
        for (i = 0; i<list.length; i++){
            fav_league_listmodel.append({"name": list[i]})
        }
    }

    Text {
        id: title

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: 10
        anchors.leftMargin: 20
        text: qsTr("Settings")
        font.family: "Nokia Pure Text Light"
        font.pixelSize: 48
        color: "white"
    }

    Rectangle {
        anchors.top: title.bottom
        width: mainPage.width
        height: 2
        color: "lightgrey"
    }

    Row {
        id: automaticUpdateSwitch

        anchors.left: parent.left
        anchors.top: title.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 10
        spacing: 110

        Text {
            id: switchText

            anchors.verticalCenter: updateSwitch.verticalCenter
            text: qsTr("Automatic update")
            font.family: "Nokia Pure Text"
            font.pixelSize: 24
            font.bold: true
            color: "lightgrey"
        }

        Switch {
            id: updateSwitch
            objectName : "switch_automatic_update"
            checked: automatic_update
            
            signal checked_changed(bool checked)

            onCheckedChanged: { checked_changed(updateSwitch.checked);
            }
        }
    }

    Text {
        id: intervalSelectionTitle
        anchors.left: parent.left
        anchors.top: automaticUpdateSwitch.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 10

        font.pixelSize: 24
        font.family: "Nokia Pure Text Light"
        text: qsTr("update interval in minutes:")
        color: "white"
        opacity: intervalSelection.opacity
    }

    ButtonRow {
        id: intervalSelection
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: intervalSelectionTitle.bottom
        anchors.topMargin: 10

        enabled: updateSwitch.checked

        Button {
            id: intervalTimeButton1
            text: "1"
            onClicked: main.save_interval_time(intervalTimeButton1.text)
            checked: interval_time == 1 ? true : false
        }

        Button {
            id: intervalTimeButton2
            text: "2"
            onClicked: main.save_interval_time(intervalTimeButton2.text)
            checked: interval_time == 2 ? true : false
        }

        Button {
            id: intervalTimeButton3
            text: "3"
            onClicked: main.save_interval_time(intervalTimeButton3.text)
            checked: interval_time == 3 ? true : false
        }

        Button {
            id: intervalTimeButton4
            text: "4"
            onClicked: main.save_interval_time(intervalTimeButton4.text)
            checked: interval_time == 4 ? true : false
        }

        Button {
            id: intervalTimeButton5
            text: "5"
            onClicked: main.save_interval_time(intervalTimeButton5.text)
            checked: interval_time == 5 ? true : false
        }

        Button {
            id: intervalTimeButton10
            text: "10"
            onClicked: main.save_interval_time(intervalTimeButton10.text)
            checked: interval_time == 10 ? true : false
        }
    }

     Rectangle {
        anchors.top: intervalSelection.bottom
        anchors.topMargin: 10
        width: mainPage.width
        height: 2
        color: "lightgrey"
    }

    Row {
        id: notificationSwitch1

        anchors.left: parent.left
        anchors.top: intervalSelection.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 30
        spacing: 90

        Text {
            id: notificationSwitchText
            text: qsTr("Notification")
            font.family: "Nokia Pure Text"
            font.pixelSize: 24
            font.bold: true
            color: "lightgrey"
        }

        Switch {
            id: notficationSwitch
            objectName : "switch_notification"
            checked: notification
            
            signal checked_changed(bool checked)

            onCheckedChanged: { checked_changed(notficationSwitch.checked);
            }
        }
    }

    Text {
        id: notificationTypeText
        anchors.left: parent.left
        anchors.top: notificationSwitch1.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 10

        text: qsTr("Type of notification:")
        color: "white"
        font.pixelSize: 24
        font.family: "Nokia Pure Text Light"
    }

    ButtonRow {
        id: notificationTypeButton
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: notificationTypeText.bottom
        anchors.topMargin: 10
        exclusive: false
        enabled: notficationSwitch.checked

        Button {
            id: notifyVibration
            objectName : "button_notif_vibrate"
            text: qsTr("Vibration")
            checkable: true
 
            signal change_notif_type(bool checked, string type)

            onClicked: {change_notif_type(notifyVibration.checked,'vibrate');
                        //rumble.start()
            }
            checked: notification_vibrate
        }

        Button {
            id: notifySound
            objectName : "button_notif_sound"
            text: qsTr("Sound")
            checkable: true

            signal change_notif_type(bool checked, string type)

            onClicked: {change_notif_type(notifySound.checked,'sound');
                        //sound.play()
            }
            checked: notification_sound
        }

        Button {
            id: notifyEvent
            objectName : "button_notif_event"
            text: qsTr("EventFeed")
            checkable: true

            signal change_notif_type(bool checked, string type)
            signal show_notification_event()

            onClicked: {change_notif_type(notifyEvent.checked,'event');
                        //show_notification_event()
            }
            checked: notification_event
        }
    }

    Rectangle {
        anchors.top: notificationTypeButton.bottom
        anchors.topMargin: 10
        width: mainPage.width
        height: 2
        color: "lightgrey"
    }

    Text {
        id: favTeamTitle
        anchors.left: parent.left
        anchors.top: notificationTypeButton.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 30

        font.pixelSize: 24
        font.family: "Nokia Pure Text Light"
        text: qsTr("favourite Team")
        color: "white"
    }
 
    Button {
         id: favTeamButton
         anchors.left: parent.left
         anchors.top: favTeamTitle.bottom
         width: parent.width-40
         anchors.leftMargin: 20
         anchors.topMargin: 10
         text: fav_team_index == 0 ? qsTr("Select your favourite Team:") : fav_team
         enabled: true
         onClicked: {create_listview_fav_teams(team_list);
                     dialog_fav_team.open()}
        }

    Rectangle {
        anchors.top: favTeamButton.bottom
        anchors.topMargin: 10
        width: mainPage.width
        height: 2
        color: "lightgrey"
    }

    Text {
        id: favLeagueTitle
        anchors.left: parent.left
        anchors.top: favTeamButton.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 30

        font.pixelSize: 24
        font.family: "Nokia Pure Text Light"
        text: qsTr("favourite League")
        color: "white"
    }

    Button {
         id: leagueButton
         anchors.left: parent.left
         anchors.top: favLeagueTitle.bottom
         width: parent.width-40
         anchors.leftMargin: 20
         anchors.topMargin: 10
         text: fav_league_index == 0 ? qsTr("1.Bundesliga") : fav_league
         enabled: true
         onClicked: {create_listview_fav_leagues(league_list);
                     dialog_fav_league.open()}
        }

    Rectangle {
        anchors.top: leagueButton.bottom
        anchors.topMargin: 10
        width: mainPage.width
        height: 2
        color: "lightgrey"
    }

    //Button {
    //     id: resetDataButton
    //     anchors.left: parent.left
    //     anchors.top: leagueButton.bottom
    //     width: parent.width-40
    //     anchors.leftMargin: 20
    //     anchors.topMargin: 50
    //     text: qsTr("Reset saved data!")
    //     enabled: false
    //     onClicked: {}
    //    }

    Row {
        id: lpm_row

        anchors.left: parent.left
        anchors.top: leagueButton.bottom
        anchors.leftMargin: 20
        anchors.topMargin: 30
        spacing: 20

        Text {
            id: switchText_lpm

            anchors.verticalCenter: lpm_row.verticalCenter
            text: qsTr("Activate Billboard Standby")
            font.family: "Nokia Pure Text"
            font.pixelSize: 24
            font.bold: true
            color: "lightgrey"
        }

        Switch {
            id: lpm_Switch
            anchors.verticalCenter: lpm_row.verticalCenter
            objectName : "switch_lpm"
            checked: lpm_switch_checked
            enabled: lpm_switch_enabled
            
            signal checked_changed(bool checked)

            onCheckedChanged: { checked_changed(lpm_Switch.checked);}
        }

        Button {
            id: button_info_lpm
            anchors.verticalCenter: lpm_row.verticalCenter
            width: button_info_lpm.height
            text: "i"
            onClicked: {infoDialog.open()}
        }
    }

    QueryDialog {
        id: infoDialog
        titleText: qsTr("Info")
        message: qsTr("If you have billboard standby screen installed, the score of your selected favourite team is shown on the standby screen.<br> MeeGoal must be running to get updates, the update interval is the selected one within Meegoal settings.<br>The information is placed at the top by default, but you can use the billboard standby editor to change the position to your needs. Just copy the string '{script:/opt/meegoal/lpm.py}' to the place you want it to be.")
        acceptButtonText: "Ok"
    }


    SelectionDialog {
        id: dialog_fav_team
        objectName: "dialog_fav_team"
        titleText: qsTr("Select your favourite Team:")
        selectedIndex: fav_team_index

        signal save_fav_team(int index)

        model: ListModel {
            id: fav_team_listmodel
            }

        onAccepted: {favTeamButton.text = fav_team_listmodel.get(dialog_fav_team.selectedIndex).name;
                     save_fav_team(dialog_fav_team.selectedIndex)}
        
    }

    SelectionDialog {
        id: dialog_fav_league
        objectName: "dialog_fav_league"
        titleText: qsTr("Select your favourite League:")
        selectedIndex: 0

        signal save_fav_league(int index)

        model: ListModel {
            id: fav_league_listmodel
            }

        onAccepted: {leagueButton.text = fav_league_listmodel.get(dialog_fav_league.selectedIndex).name;
                     save_fav_league(dialog_fav_league.selectedIndex)}
        
    }

    ToolBarLayout {
        id: settingsTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: {
                pageStack.pop()
                //pageStack.replace(Qt.resolvedUrl("MainPage.qml"))
            }
        }
    }
}
