import QtQuick 1.1
import QtMultimediaKit 1.1
import QtMobility.feedback 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1

PageStackWindow {
    id: main
    initialPage: mainPage

    signal update_(string league)
    signal update_league()
    signal next_spieltag()
    signal previous_spieltag()
    signal update_spieltag(int index)
    signal save_interval_time(string time)
    signal indexChanged(int index)

    MainPage{ id: mainPage }

    SettingsPage { id: settingsPage }

    function activateBusyIndicator(){ indicator.running = true; indicator.visible = true}
    function deactivateBusyIndicator(){ indicator.running = false; indicator.visible = false}
    function set_spieltag(spieltag){toolbutton_spieltag.text = spieltag + qsTr(".Matchday")}
    function play_sound(path_to_file){sound.source = path_to_file; sound.play()}
    function rumble(){rumbleEffect.start()}
    function change_header(str){console.log("change to" + str); mainPage.heading_text = str}
    function reset_index(){mainPage.three_screens.currentIndex = 1}
    function show_banner(str) {banner.text = str; banner.show()}
    function show_text_no_data(value) {if (value === "show") {
                                           console.log("value=" + value);
                                           mainPage.text_no_data.visible = true
                                           } 
                                       else {mainPage.text_no_data.visible = false}
                                       } 

    function show_dialog_matchday(max){
        var i = 1
        matchday_listmodel.clear()
        for (i = 1; i<= max; i++){
            matchday_listmodel.append({"name": i + qsTr(".Matchday")})
        }
        dialog_choose_matchday.open()
    }

    QueryDialog {
        id: aboutDialog
        titleText: qsTr("About MeeGoal")
        message: qsTr("MeeGoal is a frontend to show Live-Scores provided by openLigaDB. This is an open source project, so please feel free to donate or submit live data on your own.<br><br><b>Author:</b> Boris Pohler<br><b>Licence:</b> GPL 3.0<br><b>Version:</b> 0.8.0<br><br><b>Thanks:</b><br> AlphaX2 for answering all my QML-questions, Reflektorfalke for the mockups of the new design, opensmartpad.org for their help and ideas, suds")
        acceptButtonText: "Ok"
    }

    QueryDialog {
        id: helpDialog
        titleText: qsTr("Help")
        message: qsTr("Swipe left to see league's goalgetters.<br>Swipe right to see league's standings.<br>Swipe down until the ball rotates to load next matchday.<br>Swipe up until the ball rotates to load previous matchday.<br><br>Goalgetters and tables are generated out of the local data so please load previous matchdays to get data completed.")
                  
        acceptButtonText: "Ok"
    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTr("Settings"); 
                       onClicked: {(myMenu.status == DialogStatus.Open) ? myMenu.close(): {};
                                   pageStack.push(settingsPage);
                                  } 
            }
            MenuItem { text: qsTr("Help"); onClicked: {helpDialog.open()}}
            MenuItem { text: qsTr("About"); onClicked: {aboutDialog.open()} }
        }
    }

    BusyIndicator {
         id: indicator
         anchors.centerIn: parent
         platformStyle: BusyIndicatorStyle { size: "large" }
         running: false
         visible: false
    }

    InfoBanner {
         id: banner
         y: 40
         text: ""
         timerShowTime: 3000
    }

    //SoundEffect {
    //    id: sound
    //     source: "../sound/tor.mp3"
    //}

    HapticsEffect {
        id: rumbleEffect
        attackIntensity: 0
        attackTime: 250
        intensity: 1.0
        duration: 1500 // set up the duration here, in millisecond
        fadeTime: 250
        fadeIntensity: 0.0
    }

    SelectionDialog {
        id: dialog_choose_league
        titleText: qsTr("League?")
        selectedIndex: 0

        model: ListModel {
            id: leagues_listmodel
            ListElement { name: "1.Bundesliga"; shortcut: "bl1"}
            ListElement { name: "2.Bundesliga"; shortcut: "bl2"}
            ListElement { name: "3.Bundesliga"; shortcut: "bl3"}
            ListElement { name: "DFB-Pokal" ; shortcut: "dfb2013"}
            //ListElement { name: "Champions League" ;shortcut: "cl"}
            ListElement { name: "tipp3 Bundesliga"; shortcut: "OBL"}
            ListElement { name: "Premiere League"; shortcut: "PL"}
            //ListElement { name: "Primera Division" ;shortcut: "PD"}
            //ListElement { name: "Serie A" ;shortcut: "SA"}
            }

        onAccepted: { update_(leagues_listmodel.get(dialog_choose_league.selectedIndex).shortcut);
                      mainPage.heading_text = leagues_listmodel.get(dialog_choose_league.selectedIndex).name}
        }

    SelectionDialog {
        id: dialog_choose_matchday
        titleText: qsTr("Matchday?")
        selectedIndex: 0

        model: ListModel {
            id: matchday_listmodel
            }

        onAccepted: {update_spieltag(dialog_choose_matchday.selectedIndex)}
    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-refresh"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: {update_league()}
        }
        ToolButton {
            id: toolbutton_spieltag
            text: qsTr("Matchday")
            objectName: "toolbutton_spieltag"
        }
        ToolIcon { 
            platformIconId: "toolbar-list";  
            onClicked: {dialog_choose_league.open()
                       }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu";
            anchors.right: parent===undefined ? undefined : parent.right
            onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close() 
        }
    }

}
